#[repr(C)]pub struct WeightedMovingAverage {
pub period: usize,
pub weights: Vec<f64>,
pub price_type: PriceType,
pub value: f64,
pub initialized: bool,
pub inputs: ArrayDeque<f64, MAX_PERIOD, Wrapping>,
}Expand description
An indicator which calculates a weighted moving average across a rolling window.
Fields
period: usizeThe rolling window period for the indicator (> 0).
weights: Vec<f64>The weights for the moving average calculation
price_type: PriceTypePrice type
value: f64The last indicator value.
initialized: boolWhether the indicator is initialized.
inputs: ArrayDeque<f64, MAX_PERIOD, Wrapping>Inputs
Implementations
Sourceimpl WeightedMovingAverage
impl WeightedMovingAverage
Sourcepub fn new(
period: usize,
weights: Vec<f64>,
price_type: Option<PriceType>,
) -> Self
pub fn new( period: usize, weights: Vec<f64>, price_type: Option<PriceType>, ) -> Self
Creates a new WeightedMovingAverage instance.
Panics
This function panics if:
periodis zero.weights.len()does not equalperiod.weightssum is effectively zero.
Sourcepub fn new_checked(
period: usize,
weights: Vec<f64>,
price_type: Option<PriceType>,
) -> Result<Self>
pub fn new_checked( period: usize, weights: Vec<f64>, price_type: Option<PriceType>, ) -> Result<Self>
Creates a new WeightedMovingAverage instance with the given period and weights.
Errors
Returns an error if any of the validation rules fails:
periodmust be positive.weightsmust be exactlyperiodelements long.weightsmust contain at least one non-zero value (∑wᵢ > ε).